pub trait PlatformVersionedDecode: Sized {
// Required method
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>(
decoder: &mut D,
platform_version: &PlatformVersion,
) -> Result<Self, DecodeError>;
}Expand description
Trait that makes a type able to be decoded, akin to serde’s DeserializeOwned trait.
This trait should be implemented for types which do not have references to data in the reader. For types that contain e.g. &str and &[u8], implement BorrowDecode instead.
Whenever you implement Decode for your type, the base trait BorrowDecode is automatically implemented.
This trait will be automatically implemented if you enable the derive feature and add #[derive(bincode::Decode)] to your type. Note that if the type contains any lifetimes, BorrowDecode will be implemented instead.
Implementing this trait manually
If you want to implement this trait for your type, the easiest way is to add a #[derive(bincode::Decode)], build and check your target/generated/bincode/ folder. This should generate a <Struct name>_Decode.rs file.
For this struct:
struct Entity {
pub x: f32,
pub y: f32,
}It will look something like:
impl<Context> bincode::Decode<Context> for Entity {
fn decode<D: bincode::de::Decoder<Context = Context>>(
decoder: &mut D,
) -> core::result::Result<Self, bincode::error::DecodeError> {
Ok(Self {
x: bincode::Decode::decode(decoder)?,
y: bincode::Decode::decode(decoder)?,
})
}
}
impl<'de, Context> bincode::BorrowDecode<'de, Context> for Entity {
fn borrow_decode<D: bincode::de::BorrowDecoder<'de, Context = Context>>(
decoder: &mut D,
) -> core::result::Result<Self, bincode::error::DecodeError> {
Ok(Self {
x: bincode::BorrowDecode::borrow_decode(decoder)?,
y: bincode::BorrowDecode::borrow_decode(decoder)?,
})
}
}From here you can add/remove fields, or add custom logic.
To get specific integer types, you can use:
let x: u8 = bincode::Decode::decode(decoder)?;
let x = <u8 as bincode::Decode<Context>>::decode(decoder)?;Required Methods
Sourcefn platform_versioned_decode<D: Decoder<Context = BincodeContext>>(
decoder: &mut D,
platform_version: &PlatformVersion,
) -> Result<Self, DecodeError>
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given Decode.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl PlatformVersionedDecode for IpAddr
impl PlatformVersionedDecode for IpAddr
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for SocketAddr
impl PlatformVersionedDecode for SocketAddr
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for bool
impl PlatformVersionedDecode for bool
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for char
impl PlatformVersionedDecode for char
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for f32
impl PlatformVersionedDecode for f32
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for f64
impl PlatformVersionedDecode for f64
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for i8
impl PlatformVersionedDecode for i8
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for i16
impl PlatformVersionedDecode for i16
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for i32
impl PlatformVersionedDecode for i32
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for i64
impl PlatformVersionedDecode for i64
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for i128
impl PlatformVersionedDecode for i128
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for isize
impl PlatformVersionedDecode for isize
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for u8
impl PlatformVersionedDecode for u8
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for u16
impl PlatformVersionedDecode for u16
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for u32
impl PlatformVersionedDecode for u32
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for u64
impl PlatformVersionedDecode for u64
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for u128
impl PlatformVersionedDecode for u128
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for ()
impl PlatformVersionedDecode for ()
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( _: &mut D, _platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for usize
impl PlatformVersionedDecode for usize
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for Box<str>
impl PlatformVersionedDecode for Box<str>
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for CString
impl PlatformVersionedDecode for CString
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for String
impl PlatformVersionedDecode for String
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for Arc<str>
Available on target_has_atomic=ptr only.
impl PlatformVersionedDecode for Arc<str>
target_has_atomic=ptr only.fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for Ipv4Addr
impl PlatformVersionedDecode for Ipv4Addr
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for Ipv6Addr
impl PlatformVersionedDecode for Ipv6Addr
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for SocketAddrV4
impl PlatformVersionedDecode for SocketAddrV4
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for SocketAddrV6
impl PlatformVersionedDecode for SocketAddrV6
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for Duration
impl PlatformVersionedDecode for Duration
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for PathBuf
impl PlatformVersionedDecode for PathBuf
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for SystemTime
impl PlatformVersionedDecode for SystemTime
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroI8
impl PlatformVersionedDecode for NonZeroI8
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroI16
impl PlatformVersionedDecode for NonZeroI16
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroI32
impl PlatformVersionedDecode for NonZeroI32
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroI64
impl PlatformVersionedDecode for NonZeroI64
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroI128
impl PlatformVersionedDecode for NonZeroI128
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroIsize
impl PlatformVersionedDecode for NonZeroIsize
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroU8
impl PlatformVersionedDecode for NonZeroU8
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroU16
impl PlatformVersionedDecode for NonZeroU16
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroU32
impl PlatformVersionedDecode for NonZeroU32
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroU64
impl PlatformVersionedDecode for NonZeroU64
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroU128
impl PlatformVersionedDecode for NonZeroU128
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl PlatformVersionedDecode for NonZeroUsize
impl PlatformVersionedDecode for NonZeroUsize
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, _: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A> PlatformVersionedDecode for (A,)where
A: PlatformVersionedDecode,
impl<A> PlatformVersionedDecode for (A,)where
A: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B> PlatformVersionedDecode for (A, B)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
impl<A, B> PlatformVersionedDecode for (A, B)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C> PlatformVersionedDecode for (A, B, C)
impl<A, B, C> PlatformVersionedDecode for (A, B, C)
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D> PlatformVersionedDecode for (A, B, C, D)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
impl<A, B, C, D> PlatformVersionedDecode for (A, B, C, D)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E> PlatformVersionedDecode for (A, B, C, D, E)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
impl<A, B, C, D, E> PlatformVersionedDecode for (A, B, C, D, E)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F> PlatformVersionedDecode for (A, B, C, D, E, F)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
impl<A, B, C, D, E, F> PlatformVersionedDecode for (A, B, C, D, E, F)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G> PlatformVersionedDecode for (A, B, C, D, E, F, G)
impl<A, B, C, D, E, F, G> PlatformVersionedDecode for (A, B, C, D, E, F, G)
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H> PlatformVersionedDecode for (A, B, C, D, E, F, G, H)
impl<A, B, C, D, E, F, G, H> PlatformVersionedDecode for (A, B, C, D, E, F, G, H)
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I)
impl<A, B, C, D, E, F, G, H, I> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I)
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J)
impl<A, B, C, D, E, F, G, H, I, J> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J)
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
impl<A, B, C, D, E, F, G, H, I, J, K> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K, L> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
impl<A, B, C, D, E, F, G, H, I, J, K, L> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K, L, M> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
N: PlatformVersionedDecode,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
N: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
N: PlatformVersionedDecode,
O: PlatformVersionedDecode,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
N: PlatformVersionedDecode,
O: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
N: PlatformVersionedDecode,
O: PlatformVersionedDecode,
P: PlatformVersionedDecode,
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> PlatformVersionedDecode for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)where
A: PlatformVersionedDecode,
B: PlatformVersionedDecode,
C: PlatformVersionedDecode,
D: PlatformVersionedDecode,
E: PlatformVersionedDecode,
F: PlatformVersionedDecode,
G: PlatformVersionedDecode,
H: PlatformVersionedDecode,
I: PlatformVersionedDecode,
J: PlatformVersionedDecode,
K: PlatformVersionedDecode,
L: PlatformVersionedDecode,
M: PlatformVersionedDecode,
N: PlatformVersionedDecode,
O: PlatformVersionedDecode,
P: PlatformVersionedDecode,
fn platform_versioned_decode<DE: Decoder<Context = BincodeContext>>( decoder: &mut DE, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<K, V> PlatformVersionedDecode for BTreeMap<K, V>
impl<K, V> PlatformVersionedDecode for BTreeMap<K, V>
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<K, V, S> PlatformVersionedDecode for HashMap<K, V, S>
impl<K, V, S> PlatformVersionedDecode for HashMap<K, V, S>
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Cow<'_, T>
impl<T> PlatformVersionedDecode for Cow<'_, T>
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Bound<T>where
T: PlatformVersionedDecode,
impl<T> PlatformVersionedDecode for Bound<T>where
T: PlatformVersionedDecode,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Option<T>where
T: PlatformVersionedDecode,
impl<T> PlatformVersionedDecode for Option<T>where
T: PlatformVersionedDecode,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Box<[T]>where
T: PlatformVersionedDecode + 'static,
impl<T> PlatformVersionedDecode for Box<[T]>where
T: PlatformVersionedDecode + 'static,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Box<T>where
T: PlatformVersionedDecode,
impl<T> PlatformVersionedDecode for Box<T>where
T: PlatformVersionedDecode,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for BinaryHeap<T>where
T: PlatformVersionedDecode + Ord,
impl<T> PlatformVersionedDecode for BinaryHeap<T>where
T: PlatformVersionedDecode + Ord,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for BTreeSet<T>where
T: PlatformVersionedDecode + Ord,
impl<T> PlatformVersionedDecode for BTreeSet<T>where
T: PlatformVersionedDecode + Ord,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for VecDeque<T>where
T: PlatformVersionedDecode,
impl<T> PlatformVersionedDecode for VecDeque<T>where
T: PlatformVersionedDecode,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Rc<[T]>where
T: PlatformVersionedDecode + 'static,
impl<T> PlatformVersionedDecode for Rc<[T]>where
T: PlatformVersionedDecode + 'static,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_versioned: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Rc<T>where
T: PlatformVersionedDecode,
impl<T> PlatformVersionedDecode for Rc<T>where
T: PlatformVersionedDecode,
fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Arc<[T]>where
T: PlatformVersionedDecode + 'static,
Available on target_has_atomic=ptr only.
impl<T> PlatformVersionedDecode for Arc<[T]>where
T: PlatformVersionedDecode + 'static,
target_has_atomic=ptr only.fn platform_versioned_decode<D: Decoder<Context = BincodeContext>>( decoder: &mut D, platform_version: &PlatformVersion, ) -> Result<Self, DecodeError>
Sourceimpl<T> PlatformVersionedDecode for Arc<T>where
T: PlatformVersionedDecode,
Available on target_has_atomic=ptr only.
impl<T> PlatformVersionedDecode for Arc<T>where
T: PlatformVersionedDecode,
target_has_atomic=ptr only.