platform_encode_into_slice

Function platform_encode_into_slice 

pub fn platform_encode_into_slice<E: PlatformVersionEncode, C: Config>(
    val: E,
    dst: &mut [u8],
    config: C,
    platform_version: &PlatformVersion,
) -> Result<usize, EncodeError>
Encode the given value into the given slice. Returns the amount of bytes that have been written.

See the config module for more information on configurations.