platform_versioned_decode_from_reader

Function platform_versioned_decode_from_reader 

pub fn platform_versioned_decode_from_reader<D: PlatformVersionedDecode, R: Reader, C: Config>(
    reader: R,
    config: C,
    platform_version: &PlatformVersion,
) -> Result<D, DecodeError>
Attempt to decode a given type D from the given Reader.

See the config module for more information on configurations.