pub fn platform_versioned_decode_from_slice<D: PlatformVersionedDecode, C: Config>(
src: &[u8],
config: C,
platform_version: &PlatformVersion,
) -> Result<D, DecodeError>Expand description
Attempt to decode a given type D from the given slice. Returns the decoded output and the amount of bytes read.
See the config module for more information on configurations.